#
# spec file for package sapconf
#
# Copyright (c) 2019-2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

Name:           sapconf
Version:        5.0.7
Release:        150000.7.30.1
Summary:        Kernel Parameter Initializiation for SAP Systems
License:        LGPL-2.1-or-later
Group:          Productivity/Other
Url:            https://www.suse.com/partners/alliance/sap/
PreReq:         %fillup_prereq
Source0:        %name-%version.tar.gz
BuildArch:      noarch
Requires:       bc
Requires:       systemd >= 234-24.42
Requires:       sysstat
Requires:       uuidd
Requires:       logrotate
Requires:       /usr/bin/cpupower
%if 0%{?sle_version} >= 150600
Requires:       sysctl-logger
%endif
Suggests:       cron
%{?systemd_requires}

%description
The utility adjusts operating system parameters, such as kernel
tuning settings and resource limits, to allow running various
SAP solutions at satisfactory performance.

Authors:
--------
    Angela Briel, Howard Guo

%prep
%setup -q

%build

%install
mkdir -p %{buildroot}%{_libexecdir}/%{name}/
install -m 0755 lib/%{name} %{buildroot}%{_libexecdir}/%{name}/
install -m 0644 lib/common.sh %{buildroot}%{_libexecdir}/%{name}/
install -m 0644 lib/util.sh %{buildroot}%{_libexecdir}/%{name}/
install -m 0755 lib/sccu.sh %{buildroot}%{_libexecdir}/%{name}/
install -m 0755 lib/mv_tuned_conf.sh %{buildroot}%{_libexecdir}/%{name}/
install -m 0755 lib/adapt2newSNvalues.sh %{buildroot}%{_libexecdir}/%{name}/
install -m 0755 lib/sc_hooks.sh %{buildroot}%{_libexecdir}/%{name}/
install -D -m 755 lib/supportconfig-sapconf %{buildroot}%{_libexecdir}/supportconfig/plugins/%{name}

mkdir -p %{buildroot}%{_localstatedir}/lib/%{name}/saved_configs
mkdir -p %{buildroot}%{_unitdir}/systemd/system/ %{buildroot}%{_sbindir}/
install -m 0644 sapconf.service %{buildroot}%{_unitdir}/
install -m 0755 bin/* %{buildroot}%{_sbindir}/
ln -s /usr/sbin/service %{buildroot}%{_sbindir}/rcsapconf

mkdir -p %{buildroot}%{_mandir}/{man5,man7}/
install -m 0644 man/*.5 %{buildroot}%{_mandir}/man5/
install -m 0644 man/*.7 %{buildroot}%{_mandir}/man7/

mkdir -p %{buildroot}/%{_sysconfdir}/logrotate.d
install -m 0644 logrotate/%{name} %{buildroot}/%{_sysconfdir}/logrotate.d/

mkdir -p %{buildroot}/%{_fillupdir}/
pushd sysconfig
for file in *; do
    cp "$file" "%{buildroot}/%{_fillupdir}/sysconfig.$file"
done
popd

%pre
%service_add_pre sapconf.service
if [ $1 -eq 1 ]; then
    # package initial install
    # check, if old config files from a former installation still exist
    SC=/etc/sysconfig/
    for f in sapconf sapnote-1557506 sapnote-1680803; do
        if [ -f "${SC}${f}" ]; then
            mv "${SC}${f}" "${SC}${f}".rpmold || :
        fi
    done
else
    # package update
    # to prevent sapconf related tuned error messages anytime after this
    # sapconf package installation switch off tuned to remove the 'active'
    # sapconf profile
    # 'tuned-adm off' is sadly the only possibility to remove an 'active'
    # sapconf profile
    #
    # check for active tuned
    systemctl -q is-active tuned && [[ $(cat /etc/tuned/active_profile 2>/dev/null) == sap-* || $(cat /etc/tuned/active_profile 2>/dev/null) == sapconf ]] && (echo "found active tuned with a sap related profile"; touch /run/sapconf_tuned_removal_started; mkdir -p /run/sapconf; touch /run/sapconf/active; tuned-adm off; > /etc/tuned/active_profile 2>/dev/null) || :
    # if the tuned profile is a sap related profile, try to switch off tuned
    # if 'tuned-adm off' before had worked, the profile is empty
    # if not try again
    [[ $(cat /etc/tuned/active_profile 2>/dev/null) == sap-* || $(cat /etc/tuned/active_profile 2>/dev/null) == sapconf ]] && (echo "found a sap related tuned profile, try to switch off tuned"; tuned-adm off || systemctl stop tuned.service) || :
    # check for enabled and/or active sapconf.service
    sc_active=$(systemctl is-active sapconf.service 2>/dev/null) || :
    ([[ "$sc_active" == "activating" ]] || [[ "$sc_active" == "deactivating" ]] || [[ "$sc_active" == "active" ]]) && (echo "found active sapconf.service ($sc_active)"; touch /run/sapconf_pre_actss_found) || :
    systemctl -q is-enabled sapconf.service 2>/dev/null && (echo "found enabled sapconf.service"; touch /run/sapconf_pre_enblss_found) || :
    ([ ! -f /run/sapconf_tuned_removal_started ] && ([ -f /usr/lib/tuned/sapconf/script.sh ] || [ -f /usr/lib/tuned/sap-hana/script.sh ])) && touch /run/sapconf_tuned_removal_started || :
    if ([ -f /etc/sysconfig/sapnote-1557506 ] || ([ -f /etc/sysconfig/sapnote-1680803 ] && [ ! -f /etc/sysconfig/sapnote-bobj ]) || [ -f /usr/lib/tuned/sapconf/script.sh ]); then
        touch /tmp/sapconf_remove_nofile || :
    fi
    /usr/bin/md5sum /etc/sysconfig/sapconf > /tmp/sapconf_sys_md5_pre || :
    touch /run/sapconf_during_pkg_inst || :
fi

%post
if [ $1 -eq 1 ]; then
    # package initial install
    %fillup_only -n sapconf
    touch /tmp/initial_sapconf_inst || :
else
    # package update
    hook=$(%{_libexecdir}/%{name}/sc_hooks.sh del)
    if [ -f /etc/sysconfig/sapnote-1557506 ]; then
        # covers updates from SLE12 sapconf versions < 4.1.12
        echo "covers updates from SLE12 sapconf versions < 4.1.12"
        mv /etc/sysconfig/sapconf /etc/sysconfig/sapconf.rpmsave || :
        %fillup_only -n sapconf
        # remove no longer needed 'pagecache' sysconfig file
        rm -f /etc/sysconfig/sapnote-1557506 && echo "Removing obsolete /etc/sysconfig/sapnote-1557506..." || :
        # remove no longer needed 'ase' sysconfig file
        rm -f /etc/sysconfig/sapnote-1680803 && echo "Removing obsolete /etc/sysconfig/sapnote-1680803..." || :
    elif [ -f /etc/sysconfig/sapnote-1680803 ]; then
        # covers updates from SLE12 sapconf versions >= 4.1.12
        echo "covers updates from SLE12 sapconf versions >= 4.1.12"
        # remove pagecache section from sapconf sysconfig file
        # no longer supported in SLE15
        sed -i '/## Path:           SAP\/Note\/1557506 - Linux paging improvements/,/.*PAGECACHE_LIMIT_IGNORE_DIRTY[[:blank:]]*=.*/d' /etc/sysconfig/sapconf
        sed -i '/.*PAGECACHE_LIMIT_IGNORE_DIRTY[[:blank:]]*=.*/d' /etc/sysconfig/sapconf

        # bsc#1096496/bsc#1096498
        # to update the comment sections in /etc/sysconfig/sapconf
        # does not work with /bin/fillup, but is mandatory for SAP
        %{_libexecdir}/%{name}/sccu.sh || :

        echo "Updating /etc/sysconfig/sapconf ..."
        /bin/fillup -q -t /etc/sysconfig/sapconf %{_fillupdir}/sysconfig.sapconf
        # remove no longer needed 'ase' sysconfig file
        rm -f /etc/sysconfig/sapnote-1680803 && echo "Removing obsolete /etc/sysconfig/sapnote-1680803..." || :
        # remove no longer needed 'bobj' sysconfig file
        rm -f /etc/sysconfig/sapnote-bobj && echo "Removing obsolete /etc/sysconfig/sapnote-bobj..." || :
    else
        # covers updates from SLE15
        echo "covers updates from SLE15"
        # bsc#1096496/bsc#1096498
        # to update the comment sections in /etc/sysconfig/sapconf
        # does not work with /bin/fillup, but is mandatory for SAP
        %{_libexecdir}/%{name}/sccu.sh || :

        echo "Updating /etc/sysconfig/sapconf ..."
        /bin/fillup -q -t /etc/sysconfig/sapconf %{_fillupdir}/sysconfig.sapconf
    fi
    %{remove_and_set -n sapconf SEMMSL SEMMNS SEMOPM SEMMNI}
    # adapt new SAP note values to the configuration
    %{_libexecdir}/%{name}/adapt2newSNvalues.sh || :
    %{_libexecdir}/%{name}/sc_hooks.sh $hook || :

    # move custom specific sapconf related tuned profiles from /etc/tuned/
    # to /var/lib/sapconf/saved_configs
    %{_libexecdir}/%{name}/mv_tuned_conf.sh || :
    # remove nofile related limits.conf entries for @sapsys @sdba @dba
    if [ -f /tmp/sapconf_remove_nofile ]; then
        lim_chg=false
        for ulimit_group in @sapsys @sdba @dba; do
            for ulimit_type in soft hard; do
                limits_line=$(grep -E "^${ulimit_group}[[:space:]]+${ulimit_type}[[:space:]]+nofile.+" /etc/security/limits.conf)
                if [ -n "$limits_line" ]; then
                    sed -i "/$limits_line/d" /etc/security/limits.conf || :
                    lim_chg=true
                fi
            done
        done
        [[ $lim_chg ]] && echo "Updating /etc/security/limits.conf..." || :
        rm -f /tmp/sapconf_remove_nofile || :
    fi
fi

sed -i '/^[^#].*[[:blank:]][[:blank:]]*=[[:blank:]][[:blank:]]*.*/s;[[:blank:]];;g' /etc/sysconfig/sapconf >/dev/null 2>&1 || :
%service_add_post sapconf.service

# cleanup leftover - old SLE12 profile file
rm -f /var/lib/sapconf/act_profile || :

# Amend logind's behaviour (bsc#1031355, bsc#1039309, bsc#1043844), there is no rollback.
# Not needed any longer as the limit is removed from logind (jsc#SLE-10123)
SAP_LOGIN_FILE=/etc/systemd/logind.conf.d/sap.conf
if [ -f $SAP_LOGIN_FILE ]; then
    echo "removing no longer needed file '$SAP_LOGIN_FILE'"
    rm -rf $SAP_LOGIN_FILE || :
fi

%preun
%service_del_preun sapconf.service
test -n "$FIRST_ARG" || FIRST_ARG=$1
if [ $FIRST_ARG -eq 0 ]; then
    # Package removal, not upgrade
    # revert settings - not needed, done by service_del_preun

    # clean up custom specific sapconf tuned configuration
    # move custom specific sapconf related tuned profiles from /etc/tuned/
    # to /var/lib/sapconf/saved_configs
    [ ! -d /var/lib/sapconf/saved_configs ] && mkdir -p /var/lib/sapconf/saved_configs || :
    for prof in sapconf sap-hana sap-netweaver sap-ase sap-bobj; do
        if [ -f /etc/tuned/"$prof"/tuned.conf ]; then
            echo "moving custom profile /etc/tuned/$prof to /var/lib/sapconf/saved_configs"
            mv /etc/tuned/"$prof" /var/lib/sapconf/saved_configs || :
        fi
    done
fi

%postun
test -n "$FIRST_ARG" || FIRST_ARG=$1
if [ $FIRST_ARG -eq 0 ]; then
    %service_del_postun sapconf.service
    # Package removal, not upgrade - cleanup
    # remove drop-in file for ulimit settings
    if [ -f /etc/security/limits.d/sapconf-nofile.conf ]; then
        echo "removing no longer needed file '/etc/security/limits.d/sapconf-nofile.conf'"
        rm -f /etc/security/limits.d/sapconf-nofile.conf
    fi
    rm -f /run/sapconf/active /var/lib/sapconf/*profile
    rm -rf /var/lib/sapconf/saved_state
fi
# remove no longer needed UserTasksMax setting, if still available
SAP_LOGIN_FILE=/etc/systemd/logind.conf.d/sap.conf
if [ -f $SAP_LOGIN_FILE ]; then
    echo "removing no longer needed file '$SAP_LOGIN_FILE'"
    rm -rf $SAP_LOGIN_FILE
fi

%posttrans -p /bin/bash
# Use a real bash script with an explicit "exit 0" at the end to be by default fail safe
# an explicit "exit 1" must be use to enforce package install/upgrade/erase failure where needed
# see the "Shared_libraries" section in http://en.opensuse.org/openSUSE:Packaging_scriptlet_snippets
# Begin refresh systemd units and clean up possibly obsolete systemd units
# The following is a generic way how to refresh and/or clean up systemd units.
# A systemd unit may need a refresh after updating a package when the new package
# had installed a changed systemd unit file for an enabled systemd unit.
# A systemd unit may become obsolete by updating a package (see bnc#904215).
# A systemd unit is considered to have become obsolete when the systemd
# symlink /etc/systemd/system/.../unit_name -> /path/to/unit_file is broken.
# When during package update the new package does no longer provide a unit file
# then the systemd symlink becomes broken after the files of the old package
# had been actually removed by RPM.
# According to /usr/share/doc/packages/rpm/manual/triggers and according
# to https://en.opensuse.org/openSUSE:Packaging_scriptlet_snippets#Scriptlet_Ordering
# and http://fedoraproject.org/wiki/Packaging:ScriptletSnippets#Scriptlet_Ordering
# from the new package only "posttrans of new package" is run after "removal of old package"
# so that the new package must do the clean up as RPM posttrans scriptlet.
if systemctl --quiet is-enabled sapconf.service 2>/dev/null; then
    # Refresh still valid enabled systemd units and clean up possibly obsoleted systemd units:
    # Enforce systemd to use the current unit file which is usually the unit file of the new package
    # but also in case of custom units (that use other unit files) a "reenable" won't hurt because
    # "reenable" does not implicitly stop a running service which is "the right thing" because
    # a RPM package installation must not automatically disrupt (restart) a running service.
    # Using "--force reenable" is essential to clean up possibly conflicting/broken symlinks.
    # (without "|| :" build fails with "Failed to get D-Bus connection: No connection to service manager. posttrans script ... failed"):
    systemctl --quiet --force reenable sapconf.service 2>/dev/null || :
else
    # Refresh still valid disabled systemd units and clean up possibly obsoleted systemd units:
    # First using "--force reenable" is essential to clean up possibly conflicting/broken symlinks
    # because there is no "--force disable" that would clean up possibly conflicting/broken symlinks
    # see https://bugzilla.opensuse.org/show_bug.cgi?id=904215#c34
    # so that first the unit has a clean state and then it is set back to disabled (as it was before).
    # If a disabled systemd unit has become obsoleted, "systemctl --force reenable" will clean it up
    # which means the unit gets removed and the subsequent "systemctl disable" will do nothing.
    # (without "|| :" build fails with "Failed to get D-Bus connection: No connection to service manager. posttrans script ... failed"):
    systemctl --quiet --force reenable sapconf.service 2>/dev/null || :
    systemctl --quiet disable sapconf.service 2>/dev/null || :
fi
rm -f /run/sapconf_during_pkg_inst
if [ -f /tmp/initial_sapconf_inst ]; then
    # package initial install
    rm -f /tmp/initial_sapconf_inst || :
    # if saptune is active - stop and disable sapconf service
    # (jsc#SLE-10987 decision)
    saptune_active=no
    if systemd-detect-virt -q -r; then
        # running in chroot - systemctl is-active/start/stop does not work as
        # expected - acts as 'NOPs' and returns '0', but enabel/disable does work
        if [[ $(ls /etc/systemd/system/multi-user.target.wants/saptune.service 2>/dev/null) || $(cat /etc/tuned/active_profile 2>/dev/null) == "saptune" || $(ls -A /var/lib/saptune/saved_state 2>/dev/null) || $(ls -A /run/saptune/saved_state 2>/dev/null) ]]; then
            echo "Running in chroot, but detected that saptune is enabled or active. Disable sapconf service"
            systemctl disable sapconf.service || :
            saptune_active=yes
        #else - do not change system preset
        fi
    else
        if (systemctl -q is-active saptune) || (systemctl -q is-enabled saptune 2>/dev/null) || [[ $(cat /etc/tuned/active_profile 2>/dev/null) == "saptune" || $(ls -A /var/lib/saptune/saved_state 2>/dev/null) || $(ls -A /run/saptune/saved_state 2>/dev/null) ]]; then
            echo "saptune is enabled or active, stop and disable sapconf service"
            systemctl stop sapconf.service || :
            systemctl disable sapconf.service || :
            saptune_active=yes
        fi
    fi
    if [ "$saptune_active" == "no" ]; then
        td_profile=$(cat /etc/tuned/active_profile 2>/dev/null) || :
        if [ "$td_profile" != "" ]; then
            echo "found non empty active tuned profile ($td_profile), not starting sapconf service"
        elif [ -f /run/sapconf/active ]; then
            echo "found '/run/sapconf/active' file, seems sapconf already runing. So doing nothing."
        else
            echo "starting sapconf service"
            systemctl start sapconf.service || :
        fi
    fi
else
    # package update
    # check sapconf service state before update
    sapconfServEnable=false
    sapconfServActive=false
    if [ -f /run/sapconf_pre_enblss_found ] && [ -f /run/sapconf_pre_actss_found ]; then
        echo "sapconf service was active and enabled before, stay with it"
        rm -f /run/sapconf_pre_enblss_found /run/sapconf_pre_actss_found || :
        sapconfServEnable=true
        sapconfServActive=true
    fi
    if [ -f /run/sapconf_pre_enblss_found ]; then
        echo "sapconf service was enabled before, stay with it"
        rm -f /run/sapconf_pre_enblss_found || :
        sapconfServEnable=true
    fi
    if [ -f /run/sapconf_pre_actss_found ]; then
        echo "sapconf service was active before, stay with it"
        rm -f /run/sapconf_pre_actss_found || :
        sapconfServActive=true
    fi
    # if sapconf with tuned support was not used - stop and disable sapconf service
    # (jsc#SLE-10987 decision)
    if [ ! -f /run/sapconf/active ] && [ -f /run/sapconf_tuned_removal_started ]; then
        echo "sapconf with tuned support was not used"
        if [ "$sapconfServEnable" == "true" ]; then
            echo "but sapconf.service was enabled, so skip disable sapconf service"
        else
            echo "disable sapconf service"
            systemctl disable sapconf.service || :
        fi
        if [ "$sapconfServActive" == "true" ]; then
            echo "but sapconf.service was active, so skip stopping sapconf service"
        else
            echo "stop sapconf service"
            systemctl stop sapconf.service || :
        fi
    fi
    # if sapconf with tuned support was used - stop and disable tuned service
    # (jsc#SLE-10987 decision)
    # and enable and start sapconf service (bsc#1176061)
    if [ -f /run/sapconf/active ] && [ -f /run/sapconf_tuned_removal_started ]; then
        (echo "sapconf with tuned support was used, stop and disable tuned service, enable and start sapconf service"; systemctl stop tuned.service; systemctl disable tuned.service; systemctl enable sapconf.service; systemctl restart sapconf.service) || :
    fi
    # if saptune is active - stop and disable sapconf service
    # (jsc#SLE-10987 decision)
    systemctl -q is-active saptune || systemctl -q is-enabled saptune 2>/dev/null || [[ $(cat /etc/tuned/active_profile 2>/dev/null) == "saptune" || $(ls -A /var/lib/saptune/saved_state 2>/dev/null) || $(ls -A /run/saptune/saved_state 2>/dev/null) ]] && (echo "saptune is enabled or active, stop and disable sapconf service"; systemctl stop sapconf.service; systemctl disable sapconf.service) || :

    # if sapconf is/was active - reload new configuration
    if systemctl -q is-active sapconf; then
        /usr/bin/md5sum /etc/sysconfig/sapconf > /tmp/sapconf_sys_md5_post || :
        if ! (diff /tmp/sapconf_sys_md5_pre /tmp/sapconf_sys_md5_post >/dev/null 2>&1); then
            # the config in /etc/sysconfig/sapconf was changed,
            # if not already reloaded by tuned transfer  - reload config
            if [ ! -f /run/sapconf_tuned_removal_started ]; then
                echo "sapconf service is active, reload config"
                systemctl reload sapconf.service || :
            fi
        else
            echo "config in /etc/sysconfig/sapconf not changed, no need to reload config"
        fi
        # saftety net - check if really tuned.
        if [[ ! -f /run/sapconf/active || ! $(ls -A /var/lib/sapconf/saved_state 2>/dev/null) ]]; then
            echo "sapconf.service is active, but the tunings seems to be not in place, restarting..."
            systemctl restart sapconf.service || :
        fi
    fi

    # cleanup 'sapconf with tuned support' indicator
    rm -f /run/sapconf_tuned_removal_started || :

    # remove active indicator, so that a restart of sapconf after the package
    # installation will work correctly, side effect found by bsc#1176061
    ! (systemctl -q is-active sapconf) && rm -f /run/sapconf/active || :
fi
exit 0

%files
%defattr(-,root,root)
%{_sbindir}/sapconf_check
%{_sbindir}/rcsapconf
%{_unitdir}/sapconf.service
%dir %{_libexecdir}/%{name}
%{_libexecdir}/%{name}/*
%{_mandir}/man*/*
%{_fillupdir}/*
%dir %{_localstatedir}/lib/%{name}
%dir %{_localstatedir}/lib/%{name}/saved_configs
%dir %{_libexecdir}/supportconfig
%dir %{_libexecdir}/supportconfig/plugins
%{_libexecdir}/supportconfig/plugins/%{name}
#noreplace - to get sapconf.rpmnew, if file on disk has changed
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
# Created at run-time by sapconf
%attr(0755,root,root) %ghost %dir %{_localstatedir}/lib/%{name}/saved_state

%changelog
* Mon Feb 12 2024 abriel@suse.com
- version update from 5.0.6 to 5.0.7
- add require of package sysctl-logger
  (jsc#PED-5025)
- suppress error message regarding missing systemd service file
  during posttrans script
* Sat Mar  4 2023 abriel@suse.com
- version update from 5.0.5 to 5.0.6
- add parameter IGNORE_RELOAD to /etc/sysconfig/sapconf to prevent
  sapconf from changing any system tunables during package update
  (bsc#1209408)
- fix for a race condition which leads to a missing start/restart
  of sapconf, which ends up with restored kernel parameters to
  defaults
  (bsc#1207899)
* Fri Oct 21 2022 abriel@suse.com
- version update from 5.0.4 to 5.0.5
- adapt check of an active saptune service during the initial
  package installation to work in a chroot environment and fix the
  missing enablement of sapconf.
  (bsc#1190736, bsc#1190787)
* Mon Apr 25 2022 abriel@suse.com
- version update from 5.0.3 to 5.0.4
- change block device handling to handle multipath devices
  correctly. Only the DM multipath devices (mpath) will be used for
  the settings, but not its paths.
  (bsc#1188743)
- fixed wrong comparison used for setting force_latency
  (bsc#1185702)
- SAP Note 1771258 v6 updates nofile values to 1048576
  (bsc#1192841)
* Fri Aug 13 2021 abriel@suse.com
- version update from 5.0.2 to 5.0.3
- adapt the activity detection of saptune to the upcoming saptune
  version 3
  (bsc#1189496)
* Thu Mar 18 2021 abriel@suse.com
- version update from 5.0.0 to 5.0.2
- added sapconf_check and supportconfig plugin for sapconf
- change log message for 'MIN_PERF_PCT' parameter to reduce the
  spot light
  (bsc#1179524)
- add additional check to detect an active saptune service
  (started but disabled and without any notes applied).
  Improve the logging message.
  (bsc#1182314)
- enable and start sapconf.service during package update, if tuned
  is running with sapconf as profile
  (bsc#1176061)
- preserve the state of the sapconf.service during the package
  update. Only disable the sapconf service, if saptune is active.
  In any other cases don't touch the state of the sapconf service.
  If tuned has problems and the command 'tune-adm off' does not
  work properly in the preinstall script of the package, try to
  stop the tuned service to avoid weird error messages in the log
  of tuned during and after the package update
  (bsc#1182906)
* Wed May  6 2020 abriel@suse.com
- version update from 4.2.3 to 5.0.0
- check the values of the vm.dirty_* settings to be in a valid
  range before activating or restoring these system values.
  (bsc#1168067)
- add a logrotate drop-in file for sapconf to control the size of
  the /var/log/sapconf.log logfile
  (bsc#1166925)
- use a drop-in file in /etc/security/limits.d instead of modifying
  /etc/security/limits.conf directly.
  So during sapconf service start the ulimits for the max number of
  open files configured with sapconf will be written to
  /etc/security/limits.d/sapconf-nofile.conf.
  During sapconf service stop this file will be removed.
  During package update from version 4 to version 5 of sapconf the
  nofile related entries added by version 4 of sapconf will be
  removed from /etc/security/limits.conf.
  (bsc#1168840)
- support multi-queued scheduler for block devices
  (jsc#SLE-11140, jsc#SLE-11142, jsc#SLE-11143)
- remove usage of tuned from sapconf
  That means:
  Now there is only ONE configuration file for sapconf
    /etc/sysconfig/sapconf
  All trailing comment sections, which were only used for
  documentation purpose are now removed.
  All parameters of the tuned profile defined in tuned.conf
    governor, energy_perf_bias, min_perf_pct, force_latency and
    elevator
  are moved to /etc/sysconfig/sapconf
  Customer specific tuned profile changes in /etc/tuned/<profile>
  are transferred to /etc/sysconfig/sapconf. The customer specific
  tuned profile files from /etc/tuned/sapconf are moved to
  /var/lib/sapconf/saved_configs. Additional parameter settings in
  these tuned configuration files are NOT covered by sapconf.
  Additional changes during package update:
  if sapconf with tuned support was not used during package update
    stop and disable the sapconf service
  if sapconf with tuned support was used during package update
    stop and disable tuned service
  if saptune is active during package update
    stop and disable sapconf service
  To prevent sapconf related tuned error messages anytime after
  the package installation we need to switch off tuned in the
  preinstall of the package to remove the 'active' sapconf profile
  before the package installation removes the no longer shipped
  sapconf profile files. The system tuning will be restarted after
  the configuration transfer in the post phase of the package
  installation.
  (jsc#SLE-10985, jsc#SLE-10987, jsc#SLE-10988)
* Thu Mar 19 2020 abriel@suse.com
- version update from 4.2.2 to 4.2.3
- file /etc/systemd/logind.conf.d/sap.conf will be removed during
  the package update. It is not needed any longer as the limits
  for TasksMax and UserTasksMax are removed from systemd/logind
  (bsc#1148163, jsc#SLE-10123)
- if sapconf detects an improper tuned profile during start
  it will write an information to the log file and the start of
  the sapconf service will fail to guide the administrator to the
  problem.
  (bsc#1139176)
- use absolute path to script.sh in tuned.conf file
  (bsc#1124453)
- use ';' as new delimiter for a sed command in postinstall script,
  because the used '%%' is used and expanded by rpm macros.
  (bsc#1150868, bsc#1150870)
* Wed Jan 30 2019 abriel@suse.com
- source /etc/sysconfig/sapconf entries correctly, even if the
  /etc filesystem is read-only
  (bsc#1122741)
- log skipping of existing /etc/systemd/logind.conf.d/sap.conf file
  during package installation
  (bsc#1111243)
* Mon Aug 27 2018 abriel@suse.com
- Do not change the system settings for kernel.sem. So remove the
  variables SEM* from sapconf.
  (bsc#1099101)
* Fri Jun 15 2018 abriel@suse.com
- correct the SAP Note references in the man pages and in the
  sysconfig file of the sapconf package
  (bsc#1096498)
* Fri May 18 2018 abriel@suse.com
- never ever stop or disable uuidd.socket in sapconf.
  It is mandatory for every SAP application running.
  (bsc#1093843)
- remove hardcoded default value for VSZ_TMPFS_PERCENT. This allows
  an admin to exclude VSZ_TMPFS settings from the sysconfig file,
  so current system value will remain untouched.
  This value only got used in the previous version, if the variable
  VSZ_TMPFS_PERCENT was removed from the sapconf configuration file
  /etc/sysconfig/sapconf.
  If the value of the variable was only changed (increase or
  decrease) in the sapconf configuration file everything works
  fine.
  (bsc#1093844)
* Fri Apr 13 2018 abriel@suse.com
- remove the no longer needed sysconfig file
  '/etc/sysconfig/sapnote-1680803' in any update case.
  (bsc#1089549)
* Thu Apr 12 2018 abriel@suse.com
- sapconf will set ALL values specified in the file
  /etc/sysconfig/sapconf irrespective of the current system value.
  The values will be not just increase, but also decrease, if the
  value in the sysconfig file is lower than the current system
  value. All actions are logged to /var/log/sapconf.log
  (fate#325548)
- change variable names in sysconfig file for the avoidance of doubt
  (bsc#1070495)
- remove unnecessary TMPFS_SIZE_MIN from sysconfig file
  (bsc#1070496)
* Fri Apr  6 2018 abriel@suse.com
- remove the pagecache references from the sysconfig file
  during the package update from SLE12 to SLE15
  (bsc#1071539)
* Mon Mar 26 2018 abriel@suse.com
- consolidate the 4 former sapconf profiles sap-hana, sap-netweaver,
  sap-ase and sap-bobj to one basic sapconf profile 'sapconf' as
  requested by SAP.
  If one of the former profiles is the currently active tuned
  profile, the active tuned profile will be reset to the 'sapconf'
  profile during the update installation of the package.
  Additionally the no longer needed sysconfig file
  '/etc/sysconfig/sapnote-1680803' will be removed during the
  package update.
  (fate#324489, bsc#1070504)
* Tue Mar 13 2018 abriel@suse.com
- add directive ExecStop to the systemd unit file sapconf.service
  and start sapconf.service after initial package installation
  (fate#325363)
* Mon Mar 12 2018 abriel@suse.com
- add system unit file sapconf.service to start tuned, uuidd.socket
  and sysstat during system boot and to restart tuned during
  package update installation so that the changes will take effect
  immediately (fate#325363)
- remove left over pagecache limit references (bsc#1071539)
* Thu Feb 22 2018 abriel@suse.com
- Remove sapconf legacy interface
  /usr/lib/systemd/system/sapconf.service
  /usr/sbin/SAPconf
  /usr/sbin/rcsapconf
  /usr/sbin/sapconf
  The man pages are adapted to reflect the changed handling.
  (bsc#1070505, fate#324490)
* Tue Dec 19 2017 abriel@suse.com
- Check, if pagecache limit is available at the system. If yes, set
  pagecache limit according the settings in /etc/sysconfig/sapconf.
  If not, log a message to the log file.
  (bsc#1071539, fate#323778)
* Tue Dec  5 2017 abriel@suse.com
- Refactoring sapconf parameter settings together with SAP Linux Lab.
  (fate#324491)
- ATTENTION:
  One main feature of this sapconf package update to version 4.1.12
  is a consolidation of all sapconf configuration settings into the
  central /etc/sysconfig/sapconf configuration file (except those
  settings related to ASE or BOBJ and those settings which can only
  be set via tuned.conf)
  This will result in a lot of configuration file changes concerning
  /etc/sysconfig/sapconf,
  /etc/sysconfig/sapnote-1557506,
  /usr/lib/tuned/sap-netweaver/tuned.conf and
  /usr/lib/tuned/sap-hana/tuned.conf.
  That means that your system configuration get changed after a
  restart of tuned or during a system reboot.
  Please read carefully the following information about configuration
  file handling before restarting tuned or rebooting the system.
  (bsc#1070508)
- use the same tuning values for HANA and Netweaver workloads.
  That means the use of the same tuned.conf and script.sh file for
  both profiles (sap-hana and sap-netweaver)
  This should lead to a better base for mixed HANA and ABAB
  workloads on one system.
  (bsc#1070508)
- the pagecache configuration is now integrated in the general
  sapconf sysconfig file and the old sysconfig file sapnote-1557506
  is obsolete.
  As before pagecache handling is disabled by default.
  ATTENTION: configuration file handling during package installation.
  During an initial package installation the new sysconfig file,
  which includes the pagecache values from the former file
  sapnote-1557506, is copied to /etc/sysconfig/sapconf and the
  changes will take effect immediately after restarting tuned.
  During a package update previously copied /etc/sysconfig files
  will exist.
  If both files in /etc/sysconfig are unchanged - that means, there
  are no custom changes present - the new sysconfig file is copied
  to /etc/sysconfig, the old obsolete /etc/sysconfig/sapnote-1557506
  is removed and the changes will take effect immediately after
  restarting tuned.
  If the file /etc/sysconfig/sapconf is unchanged - that
  means, there are no custom changes present - but the file
  /etc/sysconfig/sapnote-1557506 contains custom modifications,
  the new sysconfig file is copied to /etc/sysconfig, the changed
  values from /etc/sysconfig/sapnote-1557506 are copied to
  /etc/sysconfig/sapconf and /etc/sysconfig/sapnote-1557506 is
  moved to /etc/sysconfig/sapnote-1557506.rmpsave. The changes
  will take effect immediately after restarting tuned.
  If the file /etc/sysconfig/sapconf contains custom modifications,
  the new sysconfig file is copied to /etc/sysconfig as sapconf.rpmnew.
  Custom modifications from /etc/sysconfig/sapnote-1557506 - if
  available - are not merged in this new file. Please merge the
  needed custom modifications manually from both files into
  /etc/sysconfig/sapconf.rpmnew, move this file to
  /etc/sysconfig/sapconf and remove /etc/sysconfig/sapnote-1557506
  before you restart tuned to get the changes take effect.
  (bsc#1070496, bsc#1070508)
- The following parameters are additional specified (instead of
  static tuning inside the tuning script or defined in other
  configuration files like tuned.conf or sapnote-1557506)
  or changed in the central configuration file
  /etc/sysconfig/sapconf.
  vm.max_map_count, vm.dirty_bytes, vm.dirty_background_bytes,
  kernel.shmmni, net.ipv4.tcp_slow_start_after_idle, ksm,
  transparent_hugepages, numa_balancing
    added and value changed
  vm.pagecache_limit_ignore_dirty, vm.pagecache_limit_mb
    added and commented out
  kernel.shmall, kernel.shmmax, kernel.sem
    changed
  But be in mind: higher system value will ever remain unchanged.
  sapconf will respect higher values set by the system or by the
  administrator using sysctl configuration files.
  Values set with sysctl command will respect too, but do not
  survive a system reboot.
  Every tuning action is logged to /var/log/sapconf.log
  ATTENTION: configuration file handling during package installation.
  During an initial package installation the new sysconfig file is
  copied to /etc/sysconfig and the changes will take effect
  immediately after restarting tuned.
  During a package update a previously copied /etc/sysconfig file
  will exist. If this file in /etc/sysconfig is unchanged - that
  means, there are no custom changes present - the new sysconfig
  file is copied to /etc/sysconfig and the changes will take effect
  immediately after restarting tuned.
  If this file in /etc/sysconfig includes custom modifications,
  the new sysconfig file is copied to /etc/sysconfig as
  sapconf.rpmnew. Please merge the needed custom modifications into
  /etc/sysconfig/sapconf.rpmnew and move this file to
  /etc/sysconfig/sapconf before you restart tuned to get the
  changes take effect
  (bsc#1070494, bsc#1070495, bsc#1070496, bsc#1070508)
- The following parameters were specified in tuned.conf of profile
  sap-hana and/or sap-netweaver before.
  But they are removed from tuned.conf because they are redundant,
  no SAP Note is mentioned it, replaced by another parameter, moved
  to another configuration file or commented out, because they are
  only valid for a special architecture or special tasks
  (like the [cpu] part was only valid for Intel architecture and
  only performance related)
  vm.swappiness, kernel.sched_min_granularity_ns,
  kernel.sched_wakeup_granularity_ns, readahead
    removed
  [cpu] section with
  governor, energy_perf_bias, min_perf_pct
    commented out
  vm.dirty_ratio, vm.dirty_background_ratio
    removed from tuned.conf
    replaced by vm.dirty_bytes, vm.dirty_background_bytes
    defined in sysconfig/sapconf
  kernel.sem, net.ipv4.tcp_slow_start_after_idle,
  transparent_hugepages
    moved to sysconfig/sapconf
  ATTENTION: these changes will take effect immediately after
  restarting tuned.
  Except the administrator is using an own copy of the tuned.conf
  file in /etc/tuned/<profile> (where <profile> may be sap-hana or
  sap-netweaver) to set own or changed values. The tuned.conf files
  in /etc/tuned/<profile> remain untouched during package
  installation. To get the new behaviour SAP is recommended, remove
  the profile copy from /etc/tuned or copy the new tuned.conf file
  from /usr/lib/tuned/<profile> to /etc/tuned/<profile> or compare
  the files in /etc/tuned/<profile> with the files in
  /usr/lib/tuned/<profile> manually and adjust the content, if
  needed.
  (bsc#1070494, bsc#1070495, bsc#1070496, bsc#1070503)
  (bsc#1048550, bsc#1064720)
- Setting of UserTasksMax, a parameter of the systemd login manager,
  will be done in the post script during the package installation.
  The value is set to 'infinity'.
  Note: A reboot is needed after the first setup to get the change
  take effect. A message will indicate if a reboot is necessary.
  As before there is no automatic rollback.
  (bsc#1070386)
- enable and start sysstat service during post script of the
  package installation (see SAP Note 1310037)
  (bsc#1070390)
- add package requirements including a short description to the man
  page of sapconf and to the central configuration file
  /etc/sysconfig/sapconf
  (bsc#1070390)
- Update the sapconf man page and associated man pages to reflect
  all the changes of sapconf package version 4.1.12
  (bsc#1070506)
- respect active tuned profile during reboot of the system
  even if it is not a 'sap' profile.
  sapconf only activates sap-netweaver profile by default, if NO
  tuned profile is actually set.
  (bsc#1026862)
- reinsert 'elevator=noop' to tuned.conf of profile sap-hana and
  sap-netweaver.
  (bsc#1031073, bsc#1032516, bsc#1070494)
* Mon Sep 18 2017 abriel@suse.com
- fix variable name for pagecache handling (bsc#1057986)
* Thu Aug 10 2017 abriel@suse.com
- restrict UserTasksMax setting to os releases > 12.1
* Fri Aug  4 2017 abriel@suse.com
- add SLE12-SP1 specific change for UserTasksMax
  (bsc#1039309 and comment #35 of bsc#1031355)
* Thu Aug  3 2017 abriel@suse.com
- add a message to %%post to remind the admin to restart the tuned
  service, if he want the configuration changes to take effect
  immediately (bsc#1048550)
* Thu Aug  3 2017 abriel@suse.com
- increase MAX_MAP_COUNT_REQ to 2147483647, see SAP Note 900929
  (bsc#1048550)
* Thu Jul 27 2017 hguo@suse.com
- Update package description.
- Make "tuned" a mandatory runtime dependency to address bsc#1043844.
- In all tuning profiles, do not overwrite a parameter if present
  value is higher than optimal value. (bsc#1048550)
* Wed Jun 21 2017 abriel@suse.com
- Amend logind's behaviour
  (bsc#1031355, bsc#1039309, bsc#1043844)
* Mon Jun 12 2017 abriel@suse.com
- Add a dependency against the package sapinit-systemd-compat to
  prevent SAP systems to be stopped every time the SAP Host Agent
  is restarted (SLE12-SP1 only)
  (bsc#1043841)
* Thu Apr 27 2017 abriel@suse.com
- add new profiles for SAP ASE (Sybase) and SAP BOBJ
  according to fate#320359.
* Thu Apr  6 2017 hguo@suse.com
- Upgrade to upstream version 4.1.7 that addresses exactly one issue:
  Lee Martin and colleagues noticed that SAP HANA performs better
  with "force_latency=70" in its tuning profile, so the setting is
  now introduced to the profile.
  (bsc#1032516)
* Mon Mar 27 2017 hguo@suse.com
- Upgrade to upstream version 4.1.6 that addresses exactly one issue:
  sapconf's sap-hana tuning profile incorrectly uses "noop" IO
  scheduler on disk block devices, which is not explicitly
  recommended by either SUSE or SAP. Performance regression showed
  up during benchmark runs. Hence, the IO scheduler setting is removed
  from tuning profile, and left to be decided by end-user.
  (bsc#1031073)
* Mon Mar  6 2017 hguo@suse.com
- Use arbitrary precision calculator rather than bash's built-in
  integer calculator to calculate parameter values, this gets rid
  of all integer overflow issues observed in production.
  (bsc#1027411)
- Apply tuning technique of Netweaver in HANA profile too.
  (bsc#1016795)
  Upgrade to upstream version 4.1.5.
* Fri Feb 17 2017 hguo@suse.com
- "force_latency=1" is removed from HANA's configuration, so that
  CPUs are no longer kept busy when idling. (bsc#1025824)
- Introduce complementary README.d and LICENSE files from upstream
  git repository.
* Tue Nov 29 2016 hguo@suse.com
- Do not touch THP configuration in Netweaver profile, avoid
  inheriting configuration from high throughput profile.
  (bsc#994306)
* Wed Jul 27 2016 hguo@suse.com
- Put version number in source archive name.
- Fix a race condition during start (bsc#977575).
* Mon Jul  4 2016 hguo@suse.com
- Start uuidd.socket as soon as the package is installed.
  Further fix bsc#983454.
* Tue Jun  7 2016 hguo@suse.com
- Control uuidd as a step of the tuning process. Fix bsc#983454.
* Mon May  2 2016 hguo@suse.com
- Introduce mandatory dependency on package tuned.
  Implement fate#320783.
* Thu Mar 31 2016 hguo@suse.com
- Redo the directory structure in the source archive file.
- Introduce /etc/sysconfig/sapnote-1557506 to:
  * Disable pagecache_limit by default.
  * Let user decide if and how to tune pagecache_limit.
  Fix bsc#966930 and bsc#971625.
* Tue Feb 23 2016 hguo@suse.com
- Mention tuned parameters in manual pages: fix bsc#966720
* Fri Jan 15 2016 hguo@suse.com
- Fix a misplaced optimisation routine that should have been
  applied to SAP HANA but in fact applied to SAP NetWeaver.
  (bsc#962059)
* Mon Sep 28 2015 hguo@suse.com
- Implement fate#319480 - [ECO] Include tuned architecture in sapconf
  * Replace the entire sapconf package content with tune daemon SAP profiles,
  * The executables remain compatible with the original sapconf implementation.
  * Following files are removed from package source:
  LGPL
  README
  SAPconf
  SAPconf-reconfig
  SAPconf.8
  config.b64
  functions
  sapconf
  sapconf.8
  sapconf.service
  * Following file is added into package source:
  sapconf.tgz
* Tue Sep 30 2014 fabian.herschel@suse.com
- bnc#899107 - Parameter of sapconf are not longer valid for e.g. Oracle installation
  problem with update on SLES12, if older defaults are already in the config
  file, fixed
* Wed Sep 10 2014 fabian.herschel@suse.com
- bnc#895978 - patterns-sles-sap_server doesn't require uuidd package
- bnc#892517 - Parameter of sapconf are not longer valid for e.g. Oracle installation
* Tue Sep  2 2014 ro@suse.de
- sanitize release line in specfile
* Wed Jul  2 2014 fabian.herschel@suse.com
- bnc#885435 - package sapconf: integration in systemd does not work correctly
* Fri Apr  4 2014 fabian.herschel@suse.com
- /etc/sysconfig/sapconf filled correctly (bnc#872073)
* Mon Feb 24 2014 fabian.herschel@suse.com
- improved integration with systemd (bnc#864933)
* Thu Feb 20 2014 fabian.herschel@suse.com
- fixed unrecoverable build (bnc#861497)
* Mon Jul 25 2011 fabian.herschel@novell.com
- fixed the detection of the tmpfs device for shared memory (bnc#693414)
* Mon May 10 2010 ro@suse.de
- add rpmlintrc as source in specfile
- drop prereq for permissions, run_permissions only runs
  for != instsys
* Mon May 10 2010 kukuk@suse.de
- Add rpmlintrc, run SuSEconfig permissions in %%post install
* Sat May  8 2010 fabian.herschel@suse.de
- Updated trigger to start uuidd via libuuid Fate#307477
- Providing prermissions file for uuidd
* Fri May  7 2010 fabian.herschel@suse.de
- Inserted requirement of uuid-runtime
- Inserted trigger script to start uuidd
* Fri Mar  5 2010 werner@suse.de
- Avoid to be fooled by `-1' for ULONG_MAX (bnc#556850)
* Wed Feb 17 2010 werner@suse.de
- Remove left over from bnc#541775
* Wed Dec 23 2009 werner@suse.de
- Enable and start sysstat boot script if sysstat is available
  with the help of a triggerin script (bnc#556850)
- Remove conflict with orarun ans it was reported that the hard
  overwrite of our values has been fixed in the package orarun
- Increase MAX_MAP_COUNT_MIN from 300.000 to 1.000.000 (bnc#525819)
* Tue Sep 29 2009 werner@suse.de
- Override -1 for SHM with real unlimited (ULONG_MAX) (bnc#541775)
* Tue Mar 10 2009 werner@suse.de
- Remove vm.hugetlb_shm_group (bnc#481496)
* Tue Jan 13 2009 werner@suse.de
- Remove vm.disable_cap_mlock (bnc#455919)
* Thu Oct 30 2008 werner@suse.de
- Ignore missing files in /proc/sys/ (bnc#440239)
* Wed Aug 13 2008 werner@suse.de
- Fix boot script and use correct Stop tags
* Wed Jul 23 2008 werner@suse.de
- Make sysstat a hard requirement (bnc#378356)
- Add sysctl parameter vm.disable_cap_mlock=1 (bnc#405094)
* Mon Jan 14 2008 werner@suse.de
- Force enabling service
* Fri Dec  7 2007 werner@suse.de
- Don't submit both sapconf and sapinit but only sapconf
* Wed Nov 28 2007 werner@suse.de
- Do not rename package for old distributions, use sapinit
- Avoid error messages from old sapinit in case of new sapinit
- Do not remove foreign sapinit rc script
* Mon Nov 26 2007 werner@suse.de
- Check max integer on 32bit platforms
- Add orarun to the conflicting packages
* Tue Nov 13 2007 werner@suse.de
- Rename spainit to spaconf
- Clean out old syssctl.conf from SAPinit
* Wed Nov  7 2007 werner@suse.de
- Add SAPINIT to Provides of boot.sapconf
- Add Suggests line with sysstat, cron, and logrotate
- If sysstat is installed boot.sapconf should depend on
* Mon Oct 29 2007 werner@suse.de
- Clean up and better error handling
* Fri Oct 26 2007 werner@suse.de
- New package sapinit from scratch version 3.0
* Fri Oct 19 2007 werner@suse.de
- More work on bug #280024
  * Make old sysctl.conf entries compact
  * Edit only modified parameters
* Wed Oct 17 2007 werner@suse.de
- Avoid multi line markers and avoid multi line entries for sysctl
  kernel parameters with vector values (bug #280024)
* Fri Sep  7 2007 DOlsson@Novell.com
- New version 2.0.2.
- The script "SAPinit" can now handle SLES 9 cases as well [#292314].
- Updated the description text in the ".spec" file.
  The text was made more clear with regards to the usage of the
  "/dev/shm" file system, as well as the various used script names.
  It now also covers the different behaviors for SLES 9 and SLES 10.
- Fixed issue under SLES 10, where a wrong sizing factoring was being
  used, when determining whether and how to do updates of the DEVSHM
  entry in FSTAB.
- Fixed issue under SLES 10, where DEVSHM got remounted, although
  there was not any reason to remount it.
* Thu Jul 12 2007 DOlsson@Novell.com
- Fixed various minor issues with the "susebuild" tag in
  "packaging/Makefile".
- Renamed "/etc/init.d/,/usr/sbin/rc}sapinit" to "sapconfig" in
  order to allow for SAP to make use of the name "sapinit" for
  their own start up script of the SAP system applications.
  [#292726 for SLES 9] and [#292727 for SLES 10].
- Updated the description text in ".spec" file to reflect the
  multiple usage of the package on SLES 9 and SLES 10.
  [#292726 for SLES 9] and [#292727 for SLES 10].
* Mon Jun 18 2007 DOlsson@Novell.com
- Removed wrong "Conflict:" statement.
* Wed May 16 2007 ro@suse.de
- remove "noarch" from specfile again.
  arch changes are not supported during SP update
* Tue May 15 2007 DOlsson@Novell.com
- Fixed specification issues in "*.spec" file with the tags
  "Provides:", "Obsoletes:", and "Conflicts:".
- Fixed issue with rearranging comments containing the "/dev/shm"
  string [#272721].
- Fixed typos in error messages issued by "SAPinit" script.
- Fixed setting of path name of the "sysconfigSAPinit" constant in
  the "SAPinit" script, when running in debugging mode.
* Tue May  8 2007 ro@suse.de
- change "test && foo" "if then foo fi" in postinstall (#272328)
* Mon May  7 2007 DOlsson@Novell.com
- In order to allow for initial system installation ([#269140] and
  [#269235]):
    + "Requires" and "Requires(post):" tags were rewritten.
    + Preventing "SAPinit" from being executed during post
    installtion.
* Fri May  4 2007 DOlsson@Novell.com
- In "SAPinit" do not use "-o mount", when only mounting the
  "/dev/shm" file system (option does not exist anymore).
- Added comments to "*.spec" file describing the usage of the
  "Provides:" tag.
- Further refined the "Provides:" and "Obsoletes:" tags.
* Thu May  3 2007 DOlsson@Novell.com
- Added instruct to stop building not needed debugging packages in
  Autobuild.
- Based on feedback from testers of the newest "sapinit" RPM package,
  the "Provides:" and "Obsoletes:" tags were refine.
- Added LSB mandentory "Short-Description:" tag to "sapinit".
* Sun Apr 22 2007 ro@suse.de
- use fillup as mandatory for sysconfig files
* Tue Apr 17 2007 DOlsson@Novell.com
- Updated ".spec" file to match that of the SUSE/Novell standards.
- Fixed "awk" output to stay in integer mode, when having huge
  figures for available virtual memory.
* Sat Apr 14 2007 DOlsson@Novell.com
- Using recommended instead of minimum value, if user has specified
  usage of "unlimited" (-1) for a parameter that does not allow
  this usage.
* Fri Apr 13 2007 DOlsson@Novell.com
- The "/etc/init.d/sapinit" script now provides "SAPINIT" instead
  of "SAP".
- Dropped "sh_opt" in "/etc/init.d/sapinit" (unknown command in
  "sh").
- In "SAPinit.sh":
  + Removed forgotten debug lines in "SAPinit.sh".
  + Prepared for option add-ons in lowering of info levels.
  + Cleaned up in information texts (making them more consistent).
  + Allowed for updating of "/etc/fstab" with actual found sizes
    instead of always using the recommended/minimum value.
  + Fixed bug in handling of the updating of "/etc/fstab", when
    "/dev/shm" is already mounted and big enough, but on entered
    in "/etc/fstab".
  + Now only activating the "/etc/sysctl.conf" parameters, when
    there is a real need for this.
- In the spec file:
  + Corrected the "Requires" to reflect what is really needed.
  + Expanded the "%%post" section with clean up facilities after the
    version 1.x series of this package.
  + Fixed a wrong setup of the "%%preun" section.
* Thu Apr 12 2007 DOlsson@Novell.com
- Updated spec file with newest required files the scripts need.
- Implemented the activation of the kernel parameters entered into
  the "/etc/sysctl.conf" file.
* Thu Apr  5 2007 DOlsson@Novell.com
- Implemented the settings of size in "/etc/fstab", when needed.
- Implemented the settings of the kernel parameters in
  "/etc/sysctl.conf", when needed.
- Updated the ".spec" file with more required commands.
- Clearified the description text in the ".spec" file (and thus in
  the README file, too).
* Fri Mar 30 2007 DOlsson@Novell.com
- Finished the last cleanups in the ".spec" file.
- Refined the "Makefile" to allow for building of needed files for
  the check-in into the SUSE/Novell build system.
- All fixes for the below mentioned bugzillas have now been implemented
  in accordance with the requirements from SAP (i.e. using recommended
  values, when nothing else specified, and allowing user to change the
  settings, but not under a certain minimum as specified by SAP):
    [#214311] Package "sapinit" sets shared memory too low
    [#197587] dedicated tmpfs /dev/shm does not exist anymore
    [#187387] "sapinit" sysctl settings for 64-bit architectures.
* Thu Mar 29 2007 DOlsson@Novell.com
- Fixed up the ".spec" file to be able to actually build the "sapinit"
  package.
- Created subdirectory "packaging" containing "Makefile" for easy
  packaging.
* Tue Mar 27 2007 DOlsson@Novell.com
- Reworked the "SAPinit.sh" script and "SAPinit" config file in order
  to be able to define the usage of recommended values (using 0) and
  in special cases "unlimited" (using -1).
- Updated the README file to match the ".spec" file.
- Added testing on "SAPinitDEBUG" to allow for reading of the
  "SAPinit" file from current directory.
- Added validation of the user defined parameters read from
  "/etc/sysconfig/SAPinit".
- Fixed the setting of the "SEM{MSL,MNS,OPM,MNI}_Cur" parameters.
- Documented the usage and hierarchy of "*_MIN[32]" and "*_ReV"
  parameters.
* Mon Mar 26 2007 DOlsson@Novell.com
- Reworked ".spec" file to now making use of a compressed TAR ball
  with the sources.
- Reworked ".spec" file in accordance with the "Packagers Manual"
  guidelines.
- Added "try-restart" as argument to "[rc]sapinit".
  Currently, it only maps to a "[rc]sapinit start".
- Updated copyright and author informations to the currently known
  correct state.
* Fri Mar 23 2007 DOlsson@Novell.com
- Added "/etc/sysconfig/SAPinit" allowing users to change the
  recommended values
- Updated the ".spec" file to only build for "noarch", while the
  scripts are architecture independed.
- Updated "SAPinit" to read the newly added "/etc/sysconfig/SAPinit"
  configuration file.
* Thu Mar 22 2007 DOlsson@Novell.com
- Renamed "sysctl-sapinit" to "SAPinit".
  Seemed to make sense, while the script is now handling a lot more
  than just setting the "sysctl" kernel parameters.
- Script completely reworked in order to be able to fullfil the SAP
  requirements for the functionality of the script.
- Script now contains hardcoded minimum and recommended values as
  defined by SAP for the various parameter values the script handles.
- Preparing script for usage of a "/etc/sysconfig/sapinit" file
  containing user defined values for the various settable parameters.
- Updated the ".spec" file to reflect the current state of the script.
* Fri Mar  9 2007 dhess@suse.de
- new version 2.0
- renamed rcsap to rcsapinit
- removed optional functionality to start SAP services at boot time automatically.
  This is usually done by using SAP mechanisms today, so not required in the OS.
- removed not longer needed sysconfig.sap and fillup macro
- removed obsolete symlinks rcsap and rcsapr3
- redirect debug info to syslog daemon (logger)
- removed SHMFS_SIZE from /etc/sysconfig/sap
  TMPFS dynamically calculated and configured in new script sysctl-sapinit
- added script sysctl-sapinit to set proper kernel paramters and to dynamically set and mount tmpfs
- removed obsolete sysctl.conf.* files
- removed obsolete script sysctl-wrapper
* Mon Sep  4 2006 stark@suse.de
- fixed fillup_and_insserv call
* Wed Aug  9 2006 stark@suse.de
- added SHMFS_SIZE to sysconfig/sapr3 and mount it via boot.sap
  service (#197587)
- only set higher sysctl values (#187387)
- renamed init script to sap
* Wed Jun 21 2006 stark@suse.de
- removed vm.heap-stack-gap as it doesn't exist in SLE10 (#186998)
* Tue Mar  7 2006 stark@suse.de
- bump version number to 1.1 (to indicate version for SLES10)
- don't install cron job for sysstat but suggest starting sysstat
  from init script (#154982)
- changed kernel.sem as requested (#135465)
* Mon Feb  6 2006 matz@suse.de
- Don't run sysctl in the build system.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Oct 24 2005 stark@suse.de
- changed values of kernel.sem
* Tue Oct 18 2005 stark@suse.de
- added LICENSE/COPYING file (#128699)
* Tue Oct 11 2005 stark@suse.de
- added vm.max_map_count parameter for all archs
* Mon Oct 10 2005 stark@suse.de
- renamed package to sapinit
- reversioned for initial autobuild checkin
* Thu Sep 29 2005 stark@suse.de
- create /etc/sysctl.conf.sap to avoid conflict with procps
- activate sapr3 init script by default to set sysctl
* Mon Aug  1 2005 stark@suse.de
- changed ppc64 settings on behalf of IBM
* Tue Jun 21 2005 stark@suse.de
- activated heap-stack setting for x86-64
* Fri Jan 21 2005 stark@suse.de
- added x86-64 architecture
* Wed Aug 25 2004 stark@suse.de
- added kernel.sem setting for all archs
* Wed Jul 21 2004 stark@suse.de
- added PPC64 architecture
- set shmfs size to 60%% for now
* Tue Feb 17 2004 stark@suse.de
- set arch dependency because of different requirements
  for kernel parameters
- added configuration for IA64
* Wed Apr 30 2003 stark@suse.de
- made /etc/sysctl.conf replaceable
* Fri Jan 24 2003 stark@suse.de
- bugfix for shmfs-size (was factor 100 too small :-()
* Thu Dec 12 2002 stark@suse.de
- added vm.heap-stack-gap to sysctl and set to 256
* Fri Oct 25 2002 stark@suse.de
- adopted for SLES8
* Fri May 17 2002 stark@suse.de
- added S/390 notes and increase shmmax to 2G
* Tue Sep  4 2001 stark@suse.de
- added msgmni settings (bjacke@suse.de)
